[svn:CPANPLUS-Dist-Build] r12757 - in CPANPLUS-Dist-Build/trunk: . lib/CPANPLUS/Dist lib/CPANPLUS/Dist/Build t/inc

[email protected]
Newsgroups perl.module.build.checkins
Message-ID <[email protected]>
Author: BINGOS
Date: Fri May  8 02:59:32 2009
New Revision: 12757

Modified:
   CPANPLUS-Dist-Build/trunk/Changes
   CPANPLUS-Dist-Build/trunk/lib/CPANPLUS/Dist/Build.pm
   CPANPLUS-Dist-Build/trunk/lib/CPANPLUS/Dist/Build/Constants.pm
   CPANPLUS-Dist-Build/trunk/t/inc/conf.pl

Log:
Add the CPANPLUS bin/ dir to {PATH} if we are running under PERL_CORE. This fixes warnings during 'make test' in the core

Modified: CPANPLUS-Dist-Build/trunk/Changes
==============================================================================
--- CPANPLUS-Dist-Build/trunk/Changes	(original)
+++ CPANPLUS-Dist-Build/trunk/Changes	Fri May  8 02:59:32 2009
@@ -1,5 +1,10 @@
 Revision history for Perl extension CPANPLUS::Dist::Build.
 
+0.28 Fri May  8 10:58:42 BST 2009
+  - Add the CPANPLUS bin/ dir to $ENV{PATH} if we are running
+    under PERL_CORE. This fixes warnings during 'make test' in
+    the core. No need for other users to upgrade.
+
 0.26 Thu May  7 16:40:26 BST 2009
   - Integrated the t/inc/conf.pl and dummy-CPAN/ structure from
     CPANPLUS into the testsuite. This resolves the issue where 

Modified: CPANPLUS-Dist-Build/trunk/lib/CPANPLUS/Dist/Build.pm
==============================================================================
--- CPANPLUS-Dist-Build/trunk/lib/CPANPLUS/Dist/Build.pm	(original)
+++ CPANPLUS-Dist-Build/trunk/lib/CPANPLUS/Dist/Build.pm	Fri May  8 02:59:32 2009
@@ -30,7 +30,7 @@
 
 local $Params::Check::VERBOSE = 1;
 
-$VERSION = '0.26';
+$VERSION = '0.28';
 
 =pod
 

Modified: CPANPLUS-Dist-Build/trunk/lib/CPANPLUS/Dist/Build/Constants.pm
==============================================================================
--- CPANPLUS-Dist-Build/trunk/lib/CPANPLUS/Dist/Build/Constants.pm	(original)
+++ CPANPLUS-Dist-Build/trunk/lib/CPANPLUS/Dist/Build/Constants.pm	Fri May  8 02:59:32 2009
@@ -9,7 +9,7 @@
     require Exporter;
     use vars    qw[$VERSION @ISA @EXPORT];
   
-    $VERSION    = '0.26';
+    $VERSION    = '0.28';
     @ISA        = qw[Exporter];
     @EXPORT     = qw[ BUILD_DIR BUILD ];
 }

Modified: CPANPLUS-Dist-Build/trunk/t/inc/conf.pl
==============================================================================
--- CPANPLUS-Dist-Build/trunk/t/inc/conf.pl	(original)
+++ CPANPLUS-Dist-Build/trunk/t/inc/conf.pl	Fri May  8 02:59:32 2009
@@ -27,11 +27,14 @@
     $ENV{'PERL5LIB'}  = join $Config{'path_sep'}, 
                         grep { defined } $ENV{'PERL5LIB'}, @paths, @rel2abs;
     
-    ### add our own path to the front of $ENV{PATH}, so that cpanp-run-perl
-    ### and friends get picked up
-    $old_env_path = $ENV{PATH};
-    $ENV{'PATH'}  = join $Config{'path_sep'}, 
-                    grep { defined } "$FindBin::Bin/../bin", $ENV{'PATH'};
+    ### add CPANPLUS' bin dir to the front of $ENV{PATH}, so that cpanp-run-perl
+    ### and friends get picked up, only under PERL_CORE though.
+    if ( $ENV{PERL_CORE} ) {
+       $old_env_path = $ENV{PATH};
+       $ENV{'PATH'}  = join $Config{'path_sep'}, 
+                    grep { defined } "$FindBin::Bin/../../../bin", $ENV{'PATH'};
+
+    }
 
     ### Fix up the path to perl, as we're about to chdir
     ### but only under perlcore, or if the path contains delimiters,
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.